KNOWLEDGE = {
    "fitts law": "The time to acquire a target is a function of the distance to and size of the target.",
    "hicks law": "The time it takes to make a decision increases with the number and complexity of choices.",
    "jakobs law": "Users spend most of their time on other sites. This means that users prefer your site to work the same way as all the other sites they already know.",
    "miller law": "The average person can only keep 7 (plus or minus 2) items in their working memory.",
    "postels law": "Be conservative in what you do, be liberal in what you accept from others."
}