KNOWLEDGE = {
    "jwt": "JSON Web Token. A compact, URL-safe means of representing claims to be transferred between two parties.",
    "oauth2": "An authorization framework that enables applications to obtain limited access to user accounts on an HTTP service.",
    "oidc": "OpenID Connect. A simple identity layer on top of the OAuth 2.0 protocol.",
    "csrf": "Cross-Site Request Forgery. An attack that forces an end user to execute unwanted actions on a web application in which they're currently authenticated.",
    "xss": "Cross-Site Scripting. A type of security vulnerability typically found in web applications. XSS attacks enable attackers to inject client-side scripts into web pages viewed by other users.",
    "hashing": "Transforming a string of characters into a usually shorter fixed-length value or key that represents the original string.",
    "salting": "Adding random data to a password before hashing it to protect against rainbow table attacks.",
    "rbac": "Role-Based Access Control. A method of restricting network access based on the roles of individual users within an enterprise."
}