KNOWLEDGE = {
    "unit test": "A level of software testing where individual units/components of a software are tested.",
    "integration test": "A level of software testing where individual units are combined and tested as a group.",
    "e2e test": "End-to-end testing. A technique that tests the entire software product from beginning to end to ensure the application flow behaves as expected.",
    "tdd": "Test-Driven Development. A software development process relying on software requirements being converted to test cases before software is fully developed.",
    "bdd": "Behavior-Driven Development. An agile software development process that encourages collaboration among developers, QA and non-technical or business participants.",
    "mocking": "Creating objects that simulate the behavior of real objects.",
    "fuzzing": "A quality assurance technique used to discover coding errors and security loopholes in software, operating systems or networks by inputting massive amounts of random data."
}