KNOWLEDGE = {
    "list comprehension": "A concise way to create lists. Common applications are to make new lists where each element is the result of some operations applied to each member of another sequence.",
    "decorator": "A design pattern in Python that allows a user to add new functionality to an existing object without modifying its structure.",
    "context manager": "Allows you to allocate and release resources precisely when you want to. The most widely used example of context managers is the `with` statement.",
    "generator": "A function that returns an iterator. It looks like a normal function except that it contains yield expressions.",
    "gil": "Global Interpreter Lock. A mutex that protects access to Python objects, preventing multiple threads from executing Python bytecodes at once.",
    "duck typing": "If it looks like a duck, swims like a duck, and quacks like a duck, then it probably is a duck."
}