KNOWLEDGE = {
    "mvc": "Model-View-Controller. Separates internal representation of information from the way information is presented to and accepted from the user.",
    "mvvm": "Model-View-ViewModel. Facilitates the separation of development of the graphical user interface from the development of the business logic or back-end logic.",
    "microservices": "An architectural style that structures an application as a collection of services that are highly maintainable and testable, loosely coupled, and independently deployable.",
    "monolith": "A software application where different components are combined into a single program from a single platform.",
    "event driven": "An architecture paradigm promoting the production, detection, consumption of, and reaction to events.",
    "serverless": "A cloud-native development model that allows developers to build and run applications without having to manage servers.",
    "clean architecture": "An architecture that separates the elements of a design into ring levels. The inner circles are policies, the outer circles are mechanisms.",
    "hexagonal": "Ports and Adapters. Allows an application to be equally driven by users, programs, automated test or batch scripts, and to be developed and tested in isolation from its eventual run-time devices and databases.",
    "cqrs": "Command Query Responsibility Segregation. Separate the read and write models of your application."
}