KNOWLEDGE = {
    "git flow": "A branching model for Git, created by Vincent Driessen. It defines a strict branching model designed around the project release.",
    "feature branch": "A temporary branch used for development of a new feature.",
    "pull request": "A method of submitting contributions to an open development project.",
    "rebase": "The process of moving or combining a sequence of commits to a new base commit.",
    "merge": "Join two or more development histories together.",
    "cherry-pick": "Apply the changes introduced by some existing commits."
}