# Path: core/lsp/base/features/definition/models.py
# -------------------------------------------------
from ...types import (
    Location, LocationLink, DefinitionParams,
    TextDocumentIdentifier, Range, Position, DocumentUri
)