# Path: core/lsp/scaffold_features/code_lens/models.py
# ------------------------------------------------
from ...base.types import (
    CodeLens, CodeLensParams, TextDocumentIdentifier, Range, Position, Command
)