# // scaffold/artisans/translocate_core/resolvers/cpp/__init__.py
# ---------------------------------------------------------------

from .engine import CppImportResolver
__all__ = ["CppImportResolver"]