KNOWLEDGE = {
    "graphql": "A query language for APIs and a runtime for fulfilling those queries with your existing data.",
    "schema": "The type system definition of the API. It defines the shape of the data graph.",
    "resolver": "A function that's responsible for populating the data for a single field in your schema.",
    "mutation": "A type of operation that allows you to modify data on the server.",
    "subscription": "A way to push data from the server to the clients that choose to listen to real time messages.",
    "fragment": "A reusable unit of a GraphQL query."
}