# Path: core/lsp/scaffold_features/code_action/models.py
# --------------------------------------------------
from ...base.types import (
    CodeAction, CodeActionKind, CodeActionParams, CodeActionContext, CodeActionOptions,
    WorkspaceEdit, Diagnostic, TextEdit, Range, Command, TextDocumentIdentifier
)