# Path: scaffold/parser_core/lexer_core/__init__.py

"""
=================================================================================
== THE SACRED GATEWAY TO THE LEXICAL CORE                                      ==
=================================================================================
This scripture is the one true, public gateway to the God-Engine of Gnostic
Perception. It proclaims the existence of the `GnosticLineInquisitor`, the
divine artisan that begins the Great Work of understanding the Architect's will.
=================================================================================
"""
from .inquisitor import GnosticLineInquisitor

# The Divine Proclamation
__all__ = ["GnosticLineInquisitor"]