# Path: core/lsp/base/features/references/models.py
# -------------------------------------------------
from ...types import (
    ReferenceParams, ReferenceContext, ReferenceOptions,
    Location, Range, Position, TextDocumentIdentifier
)