# Path: scaffold/artisans/genesis/__init__.py
# -------------------------------------------
"""The sacred gateway to the Pantheon of Genesis."""
from .conductor import GenesisArtisan

__all__ = ["GenesisArtisan"]