KNOWLEDGE = {
    "ci/cd": "Continuous Integration and Continuous Delivery/Deployment. A method to frequently deliver apps to customers by introducing automation into the stages of app development.",
    "docker": "A platform for developing, shipping, and running applications in containers.",
    "kubernetes": "An open-source system for automating deployment, scaling, and management of containerized applications.",
    "iac": "Infrastructure as Code. The process of managing and provisioning computer data centers through machine-readable definition files.",
    "gitops": "A way of implementing Continuous Deployment for cloud native applications. It focuses on a developer-centric experience when operating infrastructure.",
    "observability": "A measure of how well internal states of a system can be inferred from knowledge of its external outputs (Logs, Metrics, Traces).",
    "sla": "Service Level Agreement. A commitment between a service provider and a client.",
    "slo": "Service Level Objective. A specific target level for the performance of a service source.",
    "sli": "Service Level Indicator. A carefully defined quantitative measure of some aspect of the level of service that is provided."
}