# // scaffold/artisans/translocate_core/resolvers/java/__init__.py
# ----------------------------------------------------------------

from .engine import JavaImportResolver
__all__ = ["JavaImportResolver"]