# // scaffold/artisans/translocate_core/resolvers/ruby/__init__.py
# ----------------------------------------------------------------

from .engine import RubyImportResolver
__all__ = ["RubyImportResolver"]