# Path: scaffold/artisans/workspace/__init__.py
# ---------------------------------------------
"""The sacred gateway to the Gnostic Observatory."""
from .artisan import WorkspaceArtisan

__all__ = ["WorkspaceArtisan"]