# Path: core/lsp/scaffold_features/references/models.py
# -------------------------------------------------
from ...base.types import (
    ReferenceParams, ReferenceContext, Location, Range, Position, TextDocumentIdentifier
)