# Path: scaffold/symphony/renderers/cinematic_renderer/widgets/__init__.py
# ------------------------------------------------------------------------
from .header import HeaderWidget
from .footer import FooterWidget
from .timeline import TimelineWidget
from .output import OutputWidget
from .context import ContextWidget
from .monitor import ResourceMonitorWidget