KNOWLEDGE = {
    "websocket": "A computer communications protocol, providing full-duplex communication channels over a single TCP connection.",
    "sse": "Server-Sent Events. A standard for transmitting data updates from server to client over HTTP.",
    "webrtc": "Web Real-Time Communication. An open source project providing web browsers and mobile applications with real-time communication (RTC) via simple application programming interfaces (APIs).",
    "mqtt": "Message Queuing Telemetry Transport. A lightweight, publish-subscribe network protocol that transports messages between devices."
}