# Path: core/daemon/resolver/constants.py
# ---------------------------------------
# LIF: INFINITY | ROLE: IMMUTABLE_DNA
"""
The Immutable Laws governing Runtime Resolution.
"""

# [ENV VARS]
ENV_PYTHONPATH = "PYTHONPATH"
ENV_PATH = "PATH"
ENV_SCAFFOLD_EXE = "SCAFFOLD_EXE"
ENV_GNOSTIC_DEBUG = "GNOSTIC_DEBUG"
ENV_LOG_LEVEL = "LOG_LEVEL"

# [ENCODING LAWS]
ENV_IO_ENCODING = "PYTHONIOENCODING"
ENV_UTF8_MODE = "PYTHONUTF8"

# [VIRTUALITY MARKERS]
ENV_CONDA_PREFIX = "CONDA_PREFIX"
ENV_VIRTUAL_ENV = "VIRTUAL_ENV"

# [BYTECODE]
ENV_NO_BYTECODE = "PYTHONDONTWRITEBYTECODE"

# [LIBRARY PATHS]
ENV_LD_LIBRARY_PATH = "LD_LIBRARY_PATH"  # Linux
ENV_DYLD_LIBRARY_PATH = "DYLD_LIBRARY_PATH"  # MacOS

# [SHIM NAMES]
SHIM_WIN = "scaffold.exe"
SHIM_NIX = "scaffold"

