# Path: core/lsp/scaffold_features/definition/models.py
# -------------------------------------------------
from ...base.types import (
    Location, LocationLink, DefinitionParams, TextDocumentIdentifier,
    Range, Position, DocumentUri
)