KNOWLEDGE = {
    "promise": "An object representing the eventual completion or failure of an asynchronous operation.",
    "async/await": "Syntactic sugar built on top of promises, making asynchronous code look and behave a little more like synchronous code.",
    "closure": "The combination of a function bundled together (enclosed) with references to its surrounding state (the lexical environment).",
    "hoisting": "JavaScript's default behavior of moving declarations to the top.",
    "event loop": "The mechanism that allows Node.js/JS to perform non-blocking I/O operations.",
    "this": "A keyword that refers to the object it belongs to, depending on how a function is called."
}