# // scaffold/artisans/translocate_core/resolvers/python/__init__.py
# ------------------------------------------------------------------

from .engine import PythonImportResolver

__all__ = ["PythonImportResolver"]