# Path: artisans/introspect/__init__.py
# -------------------------------------

"""
=================================================================================
== THE SACRED GATEWAY TO THE PANTHEON OF SELF-AWARENESS (V-Ω-ETERNAL)          ==
=================================================================================
This scripture is the one true, public gateway to the Gnostic Introspection
Pantheon. It proclaims the existence of the master `IntrospectionArtisan`.
"""
from .conductor import IntrospectionArtisan

__all__ = ["IntrospectionArtisan"]