# Path: scaffold/artisans/services/twilio/constants.py
# ----------------------------------------------------

"""
THE TELEPHONIC GRIMOIRE.
Immutable laws governing the Carrier Network.
"""

# [COST BASIS USD] - For Simulation & Estimation
COST_SMS_LOCAL = "0.0079"
COST_MMS_LOCAL = "0.0200"
COST_NUMBER_LOCAL = "1.15"
COST_NUMBER_TOLLFREE = "2.15"
COST_LOOKUP_CARRIER = "0.05"
COST_LOOKUP_CNAM = "0.01"

# [PHYSICS]
GSM_CHARSET = "@£$¥èéùìòÇ\nØø\rÅåΔ_ΦΓΛΩΠΨΣΘΞ\x1b\f^{}\\[~]|€ !\"#%&'()*+,-./0123456789:;<=>?ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz"
SEGMENT_SIZE_GSM = 160
SEGMENT_SIZE_GSM_MULTI = 153
SEGMENT_SIZE_UCS2 = 70
SEGMENT_SIZE_UCS2_MULTI = 67

# [CARRIER ERROR CODES]
ERROR_MAP = {
    20003: "AUTHENTICATION_LOCKED",
    20404: "RESOURCE_VANISHED",
    21211: "COORDINATE_INVALID",
    21408: "PERMISSION_DENIED_GEO",
    21610: "BLACKLIST_BLOCK_STOP",
    21612: "SERVICE_NOT_ACTIVE",
    21614: "INCOMPATIBLE_NODE_LANDLINE",
    30003: "UNREACHABLE_DESTINATION",
    30005: "CARRIER_FILTER_UNKNOWN",
    30006: "LANDLINE_BLOCK",
    30007: "CONTENT_FILTER_SPAM",
    30008: "UNKNOWN_DELIVERY_FAILURE",
    63018: "RATE_LIMIT_EXCEEDED"
}

# [A2P DEFAULTS]
DEFAULT_USE_CASE = "LOW_VOLUME_MIXED"