# Path: core/lsp/scaffold_features/formatting/providers/__init__.py
# -----------------------------------------------------------------
from .beautifier import ScaffoldBeautifier

__all__ = ["ScaffoldBeautifier"]