# Path: core/lsp/scaffold_features/rename/models.py
# ---------------------------------------------
from ...base.types import (
    RenameParams, PrepareRenameParams, RenameOptions, WorkspaceEdit, TextEdit,
    Range, Position, TextDocumentIdentifier
)