"""
=================================================================================
== THE SANCTUM OF THE AST WEAVER (V-Ω-MODULAR-GENESIS)                         ==
=================================================================================
This sanctum houses the God-Engine that transmutes the linear stream of Time
(tokens) into the hierarchical Tree of Form (AST).
"""

from .weaver import GnosticASTWeaver

__all__ = ["GnosticASTWeaver"]