KNOWLEDGE = {
    "ec2": "Elastic Compute Cloud. Virtual servers in the cloud.",
    "s3": "Simple Storage Service. Object storage built to store and retrieve any amount of data from anywhere.",
    "lambda": "Run code without thinking about servers. Zero administration.",
    "vpc": "Virtual Private Cloud. Logically isolated section of the AWS Cloud.",
    "iam": "Identity and Access Management. Securely control access to AWS services and resources.",
    "rds": "Relational Database Service. Distributed relational database service.",
    "dynamodb": "A fully managed proprietary NoSQL database service that supports key-value and document data structures."
}