# Path: scaffold/artisans/run/prophet/__init__.py
# -----------------------------------------------

"""
=================================================================================
== THE SACRED GATEWAY TO THE PANTHEON OF PROPHECY (V-Ω-ETERNAL-FACADE)         ==
=================================================================================
This scripture is the one true, public gateway to the Gnostic Intent Prophet. It
proclaims the existence of the High Conductor to the cosmos, while shielding the
divine machinery of the internal sanctum from the outside world.
=================================================================================
"""
from .conductor import GnosticIntentProphet

__all__ = ["GnosticIntentProphet"]