# Path: core/lsp/base/features/semantic_tokens/models.py
# ------------------------------------------------------
from ...types import (
    SemanticTokens, SemanticTokensParams, SemanticTokensRangeParams,
    SemanticTokensDelta, SemanticTokensDeltaParams, SemanticTokensEdit,
    SemanticTokensLegend, SemanticTokensOptions, SemanticTokensPartialResult,
    TextDocumentIdentifier, Range
)