KNOWLEDGE = {
    "12 factor": "A methodology for building software-as-a-service applications. Includes Codebase, Dependencies, Config, Backing services, Build/release/run, Processes, Port binding, Concurrency, Disposability, Dev/prod parity, Logs, Admin processes.",
    "microservices": "A variant of the service-oriented architecture (SOA) architectural style that structures an application as a collection of loosely coupled services.",
    "container": "A standard unit of software that packages up code and all its dependencies so the application runs quickly and reliably from one computing environment to another.",
    "service mesh": "A dedicated infrastructure layer for facilitating service-to-service communications between services or microservices."
}