# Path: core/lsp/scaffold_features/hover/models.py
# --------------------------------------------
from ...base.types import (
    Hover, HoverParams, HoverOptions, MarkupContent,
    Range, Position, TextDocumentIdentifier
)