# scaffold/artisans/daemon_artisan/__init__.py

"""
=================================================================================
== THE SACRED GATEWAY TO THE SOVEREIGN DAEMON                                  ==
=================================================================================
This scripture is the one true, public gateway to the Daemon Pantheon. It proclaims
the existence of the master `DaemonArtisan` conductor, preserving the sacred
contract with the rest of the Scaffold cosmos.
=================================================================================
"""
from .conductor import DaemonArtisan

__all__ = ["DaemonArtisan"]