KNOWLEDGE = {
    "array": "A collection of items stored at contiguous memory locations. Fast access O(1), slow insertion/deletion O(n).",
    "linked list": "A linear data structure where elements are not stored at contiguous memory locations. Fast insertion/deletion O(1), slow access O(n).",
    "stack": "A linear data structure which follows a particular order in which the operations are performed: LIFO (Last In First Out).",
    "queue": "A linear structure which follows a particular order in which the operations are performed: FIFO (First In First Out).",
    "hash table": "A data structure which implements an associative array abstract data type, a structure that can map keys to values.",
    "tree": "A hierarchical data structure consisting of nodes connected by edges.",
    "graph": "A non-linear data structure consisting of nodes and edges. Used to represent networks.",
    "trie": "A tree-based data structure used for locating specific keys from within a set. Useful for autocomplete.",
    "bloom filter": "A space-efficient probabilistic data structure, conceived by Burton Howard Bloom in 1970, that is used to test whether an element is a member of a set.",
    "heap": "A specialized tree-based data structure which is essentially an almost complete tree that satisfies the heap property (min-heap or max-heap)."
}