KNOWLEDGE = {
    "refactoring": "The process of restructuring existing computer code without changing its external behavior.",
    "code smell": "A surface indication that usually corresponds to a deeper problem in the system.",
    "technical debt": "A concept in software development that reflects the implied cost of additional rework caused by choosing an easy (limited) solution now instead of using a better approach that would take longer.",
    "god object": "An object that knows too much or does too much.",
    "spaghetti code": "A pejorative phrase for unstructured and difficult-to-maintain source code."
}