KNOWLEDGE = {
    "dry": "Don't Repeat Yourself. Every piece of knowledge must have a single, unambiguous, authoritative representation within a system.",
    "kiss": "Keep It Simple, Stupid. Most systems work best if they are kept simple rather than made complicated.",
    "yagni": "You Aren't Gonna Need It. A principle of extreme programming (XP) that states a programmer should not add functionality until deemed necessary.",
    "boy scout rule": "Always leave the code better than you found it.",
    "law of demeter": "Principle of Least Knowledge. A given object should assume as little as possible about the structure or properties of anything else."
}