# Path: scaffold/artisans/translocate_core/conductor/structure_sentinel/strategies/python_strategy/__init__.py
# ------------------------------------------------------------------------------------------------------------

from .engine import PythonStructureStrategy

__all__ = ["PythonStructureStrategy"]