# Path: core/lsp/base/features/rename/models.py
# ---------------------------------------------
from ...types import (
    RenameParams, PrepareRenameParams, RenameOptions,
    WorkspaceEdit, TextEdit, Range, Position, TextDocumentIdentifier
)