KNOWLEDGE = {
    "hooks": "Functions that let you use state and other React features without writing a class.",
    "hoc": "Higher-Order Component. A function that takes a component and returns a new component.",
    "context": "Provides a way to pass data through the component tree without having to pass props down manually at every level.",
    "props drilling": "The process of passing data from a parent component down to a child component via props, often through multiple layers.",
    "virtual dom": "A programming concept where an ideal, or 'virtual', representation of a UI is kept in memory and synced with the 'real' DOM.",
    "jsx": "A syntax extension to JavaScript. Recommended for use with React to describe what the UI should look like."
}