KNOWLEDGE = {
    "acid": "Atomicity, Consistency, Isolation, Durability. Properties of database transactions.",
    "cap theorem": "Consistency, Availability, Partition tolerance. It is impossible for a distributed data store to simultaneously provide more than two out of these three guarantees.",
    "normalization": "The process of organizing data in a database. This includes creating tables and establishing relationships between those tables according to rules designed both to protect the data and to make the database more flexible.",
    "indexing": "A data structure technique which allows you to quickly retrieve records from a database file.",
    "sharding": "A type of database partitioning that separates very large databases the into smaller, faster, more easily managed parts called data shards.",
    "replication": "The process of storing data in more than one site or node. It is useful in improving the availability of data."
}