# === [scaffold/artisans/distill/core/oracle/scribe/__init__.py] - SECTION 1 of 4: The Gateway ===
"""
THE SCRIBE SANCTUM
The modular home of the Oracle Scribe and its Heralds.
"""
from .facade import OracleScribe

__all__ = ["OracleScribe"]