# Path: core/cortex/__init__.py
# -----------------------------

"""
The sacred gateway to the Gnostic Cortex, the living mind of the God-Engine.
"""
from .engine import GnosticCortex

__all__ = ["GnosticCortex"]