# Path: core/lsp/base/features/document_link/models.py
# ----------------------------------------------------
from ...types.document_link import DocumentLink, DocumentLinkParams, DocumentLinkOptions
from ...types import Range, Position


