# // scaffold/artisans/translocate_core/resolvers/rust/__init__.py
# ----------------------------------------------------------------

from .engine import RustImportResolver
__all__ = ["RustImportResolver"]