# Path: scaffold/core/ignition/diviner/sentinel/__init__.py
# --------------------------------------------------------
# LIF: INFINITY // AUTH_CODE: SENTINEL_GATEWAY_V1

from .priest import ToolchainSentinel

__all__ = ["ToolchainSentinel"]