# Path: core/lsp/base/features/folding_range/models.py
# ----------------------------------------------------

from ...types import (
    FoldingRange,
    FoldingRangeParams,
    FoldingRangeKind,
    FoldingRangeOptions,
    TextDocumentIdentifier
)